@@ -67,15 +67,15 @@ SimpleProfileSelectWidget::SimpleProfileSelectWidget(ProfileListModel *profileLi
 
     // Add buttons to the SignalMapper
     d->signalMapper->setMapping(d->ui->buttonJabber,   QLatin1String("jabber"));
+    d->signalMapper->setMapping(d->ui->buttonKDETalk,  QLatin1String("kde-talk"));
     d->signalMapper->setMapping(d->ui->buttonGTalk,    QLatin1String("google-talk"));
     d->signalMapper->setMapping(d->ui->buttonFacebook, QLatin1String("facebook"));
-    d->signalMapper->setMapping(d->ui->buttonIcq,      QLatin1String("haze-icq"));
 
     // Connect buttons to the SignalMapper
     connect(d->ui->buttonJabber,   SIGNAL(clicked()), d->signalMapper, SLOT(map()));
+    connect(d->ui->buttonKDETalk,  SIGNAL(clicked()), d->signalMapper, SLOT(map()));
     connect(d->ui->buttonGTalk,    SIGNAL(clicked()), d->signalMapper, SLOT(map()));
     connect(d->ui->buttonFacebook, SIGNAL(clicked()), d->signalMapper, SLOT(map()));
-    connect(d->ui->buttonIcq,      SIGNAL(clicked()), d->signalMapper, SLOT(map()));
     connect(d->ui->buttonOthers,   SIGNAL(clicked()), this,            SIGNAL(othersChosen()));
 
     connect(d->signalMapper,SIGNAL(mapped(QString)),
